@@ -192,26 +192,169 @@ function_data = \
      'HAVE_STRCMP': ('strcmp', 'string.h'),
      'HAVE_STRNCMP': ('strncmp', 'string.h'),
      'HAVE_VSSCANF': ('vsscanf', 'stdio.h'),
+     'HAVE_CHROOT': ('chroot', 'unistd.h'),
+     'HAVE_CLOCK': ('clock', 'time.h'),
+     'HAVE_CLOCK_GETRES': ('clock_getres', 'time.h'),
+     'HAVE_CLOCK_GETTIME': ('clock_gettime', 'time.h'),
+     'HAVE_CLOCK_SETTIME': ('clock_settime', 'time.h'),
+     'HAVE_CONFSTR': ('confstr', 'time.h'),
+     'HAVE_CTERMID': ('ctermid', 'stdio.h'),
+     'HAVE_DIRFD': ('dirfd', 'dirent.h'),
+     'HAVE_DLOPEN': ('dlopen', 'dlfcn.h'),
+     'HAVE_DUP2': ('dup2', 'unistd.h'),
+     'HAVE_DUP3': ('dup3', 'unistd.h'),
+     'HAVE_EPOLL_CREATE1': ('epoll_create1', 'sys/epoll.h'),
+     'HAVE_ERF': ('erf', 'math.h'),
+     'HAVE_ERFC': ('erfc', 'math.h'),
+     'HAVE_EXECV': ('execv', 'unistd.h'),
+     'HAVE_FACCESSAT': ('faccessat', 'unistd.h'),
+     'HAVE_FCHDIR': ('fchdir', 'unistd.h'),
+     'HAVE_FCHMODAT': ('fchmodat', 'sys/stat.h'),
+     'HAVE_FDATASYNC': ('fdatasync', 'unistd.h'),
+     'HAVE_FDOPENDIR': ('fdopendir', 'dirent.h'),
+     'HAVE_FEXECVE': ('fexecve', 'unistd.h'),
+     'HAVE_FLOCK': ('flock', 'sys/file.h'),
+     'HAVE_FORKPTY': ('forkpty', 'pty.h'),
+     'HAVE_FPATHCONF': ('fpathconf', 'unistd.h'),
+     'HAVE_FSTATAT': ('fstatat', 'unistd.h'),
+     'HAVE_FSTATVFS': ('fstatvfs', 'sys/statvfs.h'),
+     'HAVE_FTELLO': ('ftello', 'stdio.h'),
+     'HAVE_FTIME': ('ftime', 'sys/timeb.h'),
+     'HAVE_FTRUNCATE': ('ftruncate', 'unistd.h'),
+     'HAVE_FUTIMENS': ('futimens', 'sys/stat.h'),
+     'HAVE_FUTIMES': ('futimes', 'sys/time.h'),
+     'HAVE_GAI_STRERROR': ('gai_strerror', 'netdb.h'),
+     'HAVE_GETGROUPLIST': ('getgrouplist', 'grp.h'),
+     'HAVE_GETHOSTBYNAME': ('gethostbyname', 'netdb.h'),
+     'HAVE_GETHOSTBYNAME_R': ('gethostbyname_r', 'netdb.h'),
+     'HAVE_GETITIMER': ('getitimer', 'sys/time.h'),
+     'HAVE_GETLOADAVG': ('getloadavg', 'stdlib.h'),
+     'HAVE_GETLOGIN': ('getlogin', 'unistd.h'),
+     'HAVE_GETNAMEINFO': ('getnameinfo', 'netdb.h'),
+     'HAVE_GETPEERNAME': ('getpeername', 'sys/socket.h'),
+     'HAVE_GETPGID': ('getpgid', 'unistd.h'),
+     'HAVE_GETPGRP': ('getpgrp', 'unistd.h'),
+     'HAVE_GETPID': ('getpid', 'unistd.h'),
+     'HAVE_GETPRIORITY': ('getpriority', 'sys/resource.h'),
+     'HAVE_GETPWENT': ('getpwent', 'pwd.h'),
+     'HAVE_GETRANDOM': ('getrandom', 'linux/random.h'),
+     'HAVE_GETRESGID': ('getresgid', 'unistd.h'),
+     'HAVE_GETSID': ('getsid', 'unistd.h'),
+     'HAVE_GETSPENT': ('getspent', 'shadow.h'),
+     'HAVE_GETSPNAM': ('getspnam', 'shadow.h'),
+     'HAVE_GETWD': ('getwd', 'unistd.h'),
+     'HAVE_HSTRERROR': ('hstrerror', 'netdb.h'),
+     'HAVE_HTOLE64': ('htole64', 'endian.h'),
+     'HAVE_IF_NAMEINDEX': ('if_nameindex', 'net/if.h'),
+     'HAVE_INET_ATON': ('inet_aton', 'arpa/inet.h'),
+     'HAVE_INET_PTON': ('inet_pton', 'arpa/inet.h'),
+     'HAVE_INITGROUPS': ('initgroups', 'grp.h'),
+     'HAVE_KILL': ('kill', 'signal.h'),
+     'HAVE_KILLPG': ('killpg', 'signal.h'),
+     'HAVE_LINKAT': ('linkat', 'unistd.h'),
+     'HAVE_LOCKF': ('lockf', 'unistd.h'),
+     'HAVE_LUTIMES': ('lutimes', 'sys/time.h'),
+     'HAVE_MAKEDEV': ('makedev', 'sys/sysmacros.h'),
+     'HAVE_MBRTOWC': ('mbrtowc', 'wchar.h'),
+     'HAVE_MEMRCHR': ('memrchr', 'string.h'),
+     'HAVE_MKDIRAT': ('mkdirat', 'sys/stat.h'),
+     'HAVE_MKFIFOAT': ('mkfifoat', 'sys/stat.h'),
+     'HAVE_MKNOD': ('mknod', 'unistd.h'),
+     'HAVE_MKNODAT': ('mknodat', 'unistd.h'),
+     'HAVE_MKTIME': ('mktime', 'unistd.h'),
+     'HAVE_MKREMAP': ('mkremap', 'sys/mman.h'),
+     'HAVE_NICE': ('nice', 'unistd.h'),
+     'HAVE_OPENAT': ('openat', 'fcntl.h'),
+     'HAVE_OPENPTY': ('openpty', 'pty.h'),
+     'HAVE_PATHCONF': ('pathconf', 'unistd.h'),
+     'HAVE_PAUSE': ('pause', 'unistd.h'),
+     'HAVE_PREAD': ('pread', 'unistd.h'),
+     'HAVE_PTHREAD_KILL': ('pthread_kill', 'signal.h'),
+     'HAVE_PTHREAD_SIGMASK': ('pthread_sigmask', 'signal.h'),
+     'HAVE_PWRITE': ('pwrite', 'unistd.h'),
+     'HAVE_READLINKAT': ('readlinkat', 'unistd.h'),
+     'HAVE_READV': ('readv', 'sys/uio.h'),
+     'HAVE_RENAMEAT': ('renamat', 'stdio.h'),
+     'HAVE_SCHED_GET_PRIORITY_MAX': ('sched_get_priority_max', 'sched.h'),
+     'HAVE_SCHED_RR_GET_INTERVAL': ('sched_rr_get_interval', 'sched.h'),
+     'HAVE_SCHED_SETAFFINITY': ('sched_setaffinity', 'sched.h'),
+     'HAVE_SCHED_SETPARAM': ('sched_setparam', 'sched.h'),
+     'HAVE_SCHED_SETSCHEDULER': ('sched_setscheduler', 'sched.h'),
+     'HAVE_SELECT': ('select', 'sys/select.h'),
+     'HAVE_SEM_GETVALUE': ('sem_getvalue', 'semaphore.h'),
+     'HAVE_SEM_OPEN': ('sem_open', 'semaphore.h'),
+     'HAVE_SEM_TIMEDWAIT': ('sem_timedwait', 'semaphore.h'),
+     'HAVE_SEM_UNLINK': ('sem_unlink', 'semaphore.h'),
+     'HAVE_SENDFILE': ('sendfile', 'sys/sendfile.h'),
+     'HAVE_SETGID': ('setgid', 'unistd.h'),
+     'HAVE_SETGROUPS': ('setgroups', 'grp.h'),
+     'HAVE_SETHOSTNAME': ('sethostname', 'unistd.h'),
+     'HAVE_SETITIMER': ('setitimer', 'sys/time.h'),
+     'HAVE_SETLOCALE': ('setlocale', 'locale.h'),
+     'HAVE_SETPGRP': ('setpgrp', 'unistd.h'),
+     'HAVE_SETPRIORITY': ('setpriority', 'sys/resource.h'),
+     'HAVE_SETREUID': ('setreuid', 'unistd.h'),
+     'HAVE_SETSID': ('setsid', 'unistd.h'),
+     'HAVE_SETUID': ('setuid', 'unistd.h'),
+     'HAVE_SETVBUF': ('setvbuf', 'unistd.h'),
+     'HAVE_SIGALTSTACK': ('sigaltstack', 'signal.h'),
+     'HAVE_SIGINTERRUPT': ('siginterrupt', 'signal.h'),
+     'HAVE_SIGPENDING': ('sigpending', 'signal.h'),
+     'HAVE_SIGRELSE': ('sigrelse', 'signal.h'),
+     'HAVE_SIGTIMEDWAIT': ('sigtimedwait', 'signal.h'),
+     'HAVE_SIGWAIT': ('sigwait', 'signal.h'),
+     'HAVE_SIGWAITINFO': ('sigwaitinfo', 'signal.h'),
+     'HAVE_SOCKETPAIR': ('socketpair', 'sys/socket.h'),
+     'HAVE_STRFTIME': ('strftime', 'time.h'),
+     'HAVE_SYMLINKAT': ('symlinkat', 'unistd.h'),
+     'HAVE_SYNC': ('sync', 'unistd.h'),
+     'HAVE_TCGETPGRP': ('tcgetpgrp', 'unistd.h'),
+     'HAVE_TCSETPGRP': ('tcsetpgrp', 'unistd.h'),
+     'HAVE_TEMPNAM': ('tempnam', 'stdio.h'),
+     'HAVE_TIMES': ('times', 'sys/times.h'),
+     'HAVE_TEMPFILE': ('tempfile', 'stdio.h'),
+     'HAVE_TMPNAM': ('tmpnam', 'stdio.h'),
+     'HAVE_TMPNAM_R': ('tmpnam_r', 'stdio.h'),
+     'HAVE_TRUNCATE': ('truncate', 'unistd.h'),
+     'HAVE_TZNAME': ('tzname', 'time.h'),
+     'HAVE_UNAME': ('uname', 'sys/utsname.h'),
+     'HAVE_UNLINKAT': ('unlinkat', 'unistd.h'),
+     'HAVE_UTIMENSAT': ('utimensat', 'sys/stat.h'),
+     'HAVE_WAIT3': ('wait3', 'sys/wait.h'),
+     'HAVE_WAIT4': ('wait4', 'sys/wait.h'),
+     'HAVE_WAITID': ('waitid', 'sys/wait.h'),
+     'HAVE_WRITEV': ('writev', 'sys/uio.h'),
+     'HAVE_WMEMCMP': ('wmemcmp', 'wchar.h'),
      'HAVE_ATAN': ('atan', 'math.h'),
      'HAVE_ATAN2': ('atan2', 'math.h'),
      'HAVE_ACOS': ('acos', 'math.h'),
+     'HAVE_ACOSH': ('acosh', 'math.h'),
      'HAVE_ASIN': ('asin', 'math.h'),
      'HAVE_ASINH': ('asinh', 'math.h'),
+     'HAVE_ATANH': ('atanh', 'math.h'),
      'HAVE_CEIL': ('ceil', 'math.h'),
      'HAVE_COPYSIGN': ('copysign', 'math.h'),
      'HAVE_COS': ('cos', 'math.h'),
      'HAVE_COSH': ('cosh', 'math.h'),
      'HAVE_COSF': ('cosf', 'math.h'),
+     'HAVE_EXPM1': ('expm1', 'math.h'),
      'HAVE_FABS': ('fabs', 'math.h'),
+     'HAVE_FINITE': ('finite', 'math.h'),
      'HAVE_FLOOR': ('floor', 'math.h'),
+     'HAVE_GAMMA': ('gamma', 'math.h'),
+     'HAVE_HYPOT': ('hypot', 'math.h'),
      'HAVE_ISINF': ('isinf', 'math.h'),
      'HAVE_LOG': ('log', 'math.h'),
+     'HAVE_LOG1P': ('log1p', 'math.h'),
+     'HAVE_LOG2': ('log2', 'math.h'),
+     'HAVE_LGAMMA': ('lgamma', 'math.h'),
      'HAVE_POW': ('pow', 'math.h'),
      'HAVE_SCALBN': ('scalbn', 'math.h'),
      'HAVE_SIN': ('sin', 'math.h'),
      'HAVE_SINF': ('sinf', 'math.h'),
      'HAVE_SINH': ('sinh', 'math.h'),
      'HAVE_SQRT': ('sqrt', 'math.h'),
+     'HAVE_TGAMMA': ('tgamma', 'math.h'),
      'HAVE_FSEEKO': ('fseeko', 'stdio.h'),
      'HAVE_FSEEKO64': ('fseeko64', 'stdio.h'),
      'HAVE_SETJMP': ('setjmp', 'setjmp.h'),
